require_relative '../../spec_helper'

describe "Agencies" do

  describe "match method to class" do
    it "must match" do
      Frizzle.agencies.must_be_same_as Frizzle::Agencies
    end
  end

  describe "GET agencies" do
    let(:agencies) { Frizzle::Agencies.all }

    before do
      VCR.insert_cassette 'agencies', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.all
    end

    it "must get the right agency name" do
      agencies[0]['long_name'].must_equal "Chapel Hill Transit"
    end

    it "must get the right agency language" do
      agencies[0]['language'].must_equal "en"
    end

    it "must return the right agency id" do
      agencies[0]['agency_id'].must_equal "8"
    end
  end

  describe "GET agencies with option hash" do
    let(:agencies_find_options) { Frizzle::Agencies.find({:agencies => "12", :geo_area => "35.80176,-78.64347|100"}) }

    before do
      VCR.insert_cassette 'agencies_find_options'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.find({:agencies => "12", :geo_area => "35.80176,-78.64347|100"})
    end

    it "must get the right agency name" do
      agencies_find_options[0]['long_name'].must_equal "Triangle Transit"
    end

    it "must return the right agency id" do
      agencies_find_options[0]['agency_id'].must_equal "12"
    end

  end

  describe "GET agencies by id" do
    let(:agencies_id) { Frizzle::Agencies.find_by_id("168") }

    before do
      VCR.insert_cassette 'agency_id', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.find_by_id("168")
    end

    it "must get the right agency name" do
      agencies_id[0]['long_name'].must_equal "Kennesaw State University"
    end

    it "must get the right agency language" do
      agencies_id[0]['language'].must_equal "en"
    end

    it "must return the right agency id" do
      agencies_id[0]['agency_id'].must_equal "168"
    end
  end

  describe "GET agencies by id and geo area" do
    let(:agencies_id_geo) { Frizzle::Agencies.find_by_id_and_geo_area("168", [35.80176,-78.64347]) }

    before do
      VCR.insert_cassette 'agencies_id_geo', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.find_by_id_and_geo_area("168", [35.80176,-78.64347])
    end

  end

  describe "GET agencies by geo radius" do
    let(:agencies_geo_radius) { Frizzle::Agencies.find_by_geo_area([35.80176,-78.64347], 75.5) }

    before do
      VCR.insert_cassette 'agency_geo_radius', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.find_by_geo_area([35.80176,-78.64347], 75.5)
    end

    it "must get the right first agency name" do
      agencies_geo_radius[0]['long_name'].must_equal "Triangle Transit"
    end
  end

  describe "GET agencies by geo radius with default radius" do
    let(:agencies_geo_default_radius) { Frizzle::Agencies.find_by_geo_area([35.80176,-78.64347]) }

    before do
      VCR.insert_cassette 'agencies_geo_default_radius', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.find_by_geo_area([35.80176,-78.64347])
    end

    it "must get the right first agency name" do
      agencies_geo_default_radius[0]['long_name'].must_equal "Triangle Transit"
    end
  end

  describe "GET agencies by geo rectangle" do
    let(:agencies_geo_rectangle) { Frizzle::Agencies.find_by_geo_area([35.80176,-78.64347], [35.78061,-78.68218]) }

    before do
      VCR.insert_cassette 'agencies_geo_rectangle', :record => :new_episodes
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Agencies.find_by_geo_area([35.80176,-78.64347], [35.78061,-78.68218])
    end

    it "must get the right first agency name" do
      agencies_geo_rectangle[0]['long_name'].must_equal "Triangle Transit"
    end
  end

end