require_relative '../../spec_helper'

describe "Base" do

  describe "default attributes" do

    it "must include default HTTParty attributes" do
      Frizzle::Base.must_include HTTParty
    end

    it "must include the Singleton class" do
      Frizzle::Base.must_include Singleton
    end

  end

  describe "must include correct constants" do

    it "must have the base url set to the Transloc API endpoint" do
      Frizzle::Base.base_uri.must_equal "http://api.transloc.com/#{Frizzle::Base::API_VERSION}"
    end

    it "must have the API version match the Transloc API version" do
      Frizzle::Base::API_VERSION.must_equal "1.2"
    end

  end

  describe "it must use methods correctly" do

    it "must detect if number is a number correctly" do
      Frizzle::Base.is_numeric?(9).must_equal true
    end

    it "must detect if number is a number correctly" do
      Frizzle::Base.is_numeric?("9").must_equal true
    end

    it "must detect if a non-number isn't a number correctly" do
      Frizzle::Base.is_numeric?("asdf").must_equal false
    end

    it "must detect if an array isn't a number correctly" do
      Frizzle::Base.is_numeric?([98,12]).must_equal false
    end

    it "must format arrays correctly" do
      Frizzle::Base.formatted_list(["123,644,901"]).must_equal "123,644,901"
    end

    it "must format strings correctly" do
      Frizzle::Base.formatted_list("123,644,901").must_equal "123,644,901"
    end

    it "must format strings correctly" do
      Frizzle::Base.formatted_list("123,644,901").must_equal "123,644,901"
    end

    it "must format numbers correctly" do
      Frizzle::Base.formatted_list(123).must_equal "123"
    end

    it "must format number arrays correctly" do
      Frizzle::Base.formatted_list([123,456,789]).must_equal "123,456,789"
    end

    it "must format geo rectangle correctly" do
      Frizzle::Base.formatted_geo_area([36,36],[87,87]).must_equal "36,36|87,87"
    end

    it "must format geo rectangle correctly" do
      Frizzle::Base.formatted_geo_area(['36','36'],['87','87']).must_equal "36,36|87,87"
    end

    it "must format geo radius correctly" do
      Frizzle::Base.formatted_geo_area(['36','36'],65).must_equal "36,36|65"
    end

    it "must format geo radius correctly with strings in array" do
      Frizzle::Base.formatted_geo_area(['36','36'],65).must_equal "36,36|65"
    end

    it "must format geo radius correctly with numbers in array" do
      Frizzle::Base.formatted_geo_area([36,36],65).must_equal "36,36|65"
    end

    it "must format geo radius correctly with radius as string" do
      Frizzle::Base.formatted_geo_area([36,36],'65').must_equal "36,36|65"
    end

    it "must format attributes correctly" do
      lambda { Frizzle::Base.formatted_geo_area(65,65) }.must_raise ArgumentError
    end

    it "must have correct number of attributes" do
      lambda { Frizzle::Base.formatted_geo_area(65) }.must_raise ArgumentError
    end

    it "must have default radius of 100 meters" do
      Frizzle::Base.formatted_geo_area([35,-78]).must_equal "35,-78|100"
    end

  end

end