require_relative '../../spec_helper'

describe "Routes" do

  describe "match method to class" do
    it "must match" do
      Frizzle.routes.must_be_same_as Frizzle::Routes
    end
  end

  describe "find routes with hash" do
    let(:routes_find_options) { Frizzle::Routes.find({:agencies => "24"}) }

    before do
      VCR.insert_cassette 'routes_find_options'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Routes.find({:agencies => "24"})
    end

    it "must match the right route id" do
      routes_find_options['24'][0]['route_id'].must_equal "4000076"
    end

    it "must match the right route color" do
      routes_find_options['24'][0]['color'].must_equal "23a135"
    end
  end

  describe "find routes by agencies" do
    let(:routes_agencies) { Frizzle::Routes.find_by_agencies("24") }

    before do
      VCR.insert_cassette 'routes_agencies'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Routes.find_by_agencies("24")
    end

    it "must match the right route id" do
      routes_agencies['24'][0]['route_id'].must_equal "4000076"
    end

    it "must match the right route color" do
      routes_agencies['24'][0]['color'].must_equal "23a135"
    end

  end

  describe "find routes by agencies and geo area" do
    let(:routes_agencies_geo) { Frizzle::Routes.find_by_agencies_and_geo_area(24, [35.98974,-78.90292]) }

    before do
      VCR.insert_cassette 'routes_agencies_geo'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Routes.find_by_agencies_and_geo_area(24, [35.98974,-78.90292])
    end

    it "must match the right route id" do
      routes_agencies_geo['24'][0]['route_id'].must_equal "4000079"
    end

    it "must match the right route color" do
      routes_agencies_geo['24'][0]['color'].must_equal "a05728"
    end

  end

end