require_relative '../../spec_helper'

describe "Segments" do

  describe "match method to class" do
    it "must match" do
      Frizzle.segments.must_be_same_as Frizzle::Segments
    end
  end

  describe "find segments with hash" do
    let(:segments_find_options) { Frizzle::Segments.find({:agencies => "24"}) }

    before do
      VCR.insert_cassette 'segments_find_options'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Segments.find({:agencies => "24"})
    end

    it "must be the correct polyline" do
      segments_find_options['4012039'].must_equal "g_fzErly_NtCdBdA~@lAlAbAv@`BbA"
    end
  end

  describe "find segments with agencies id" do
    let(:segments_agency_id) { Frizzle::Segments.find_by_agencies(24) }

    before do
      VCR.insert_cassette 'segments_agency_id'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Segments.find_by_agencies(24)
    end

    it "must be the correct polyline" do
      segments_agency_id['4012039'].must_equal "g_fzErly_NtCdBdA~@lAlAbAv@`BbA"
    end
  end

  describe "find segments with agencies and routes" do
    let(:segments_agency_and_route) { Frizzle::Segments.find_by_agencies_and_routes(24, [4000078, 4000383]) }

    before do
      VCR.insert_cassette 'segments_agency_and_route'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Segments.find_by_agencies_and_routes(24, [4000078, 4000383])
    end

    it "must get the correct polyline" do
      segments_agency_and_route['4039943'].must_equal "}uwzEbez`NsAwAo@w@q@mAQc@U}@MmAWcI"
    end
  end

  describe "find segments with agencies and geo" do
    let(:segments_agency_and_geo_area) { Frizzle::Segments.find_by_agencies_and_geo_area(24, [35.98974,-78.90292]) }

    before do
      VCR.insert_cassette 'segments_agency_and_geo_area'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Segments.find_by_agencies_and_geo_area(24, [35.98974,-78.90292])
    end

    it "must get the correct polyline" do
      segments_agency_and_geo_area['4043399'].must_equal "s|szEvrq`NUJi@PWPcBxBc@TMBc@@k[cK"
    end
  end

end