require_relative '../../spec_helper'

describe "Vehicles" do

  describe "match method to class" do
    it "must match" do
      Frizzle.vehicles.must_be_same_as Frizzle::Vehicles
    end
  end

  describe "find stops with hash" do
    let(:vehicles_find_options) { Frizzle::Vehicles.find({:agencies => "24"}) }

    before do
      VCR.insert_cassette 'vehicles_find_options'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Vehicles.find({:agencies => "24"})
    end

    it "must have the correct call name" do
      vehicles_find_options['24'][0]['call_name'].must_equal "1002"
    end
  end

  describe "find stops with agencies" do
    let(:vehicles_agencies) { Frizzle::Vehicles.find_by_agencies("24") }

    before do
      VCR.insert_cassette 'vehicles_agencies'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Vehicles.find_by_agencies("24")
    end

    it "must have the correct call name" do
      vehicles_agencies['24'][0]['call_name'].must_equal "1002"
    end
  end

  describe "find stops with agencies and routes" do
    let(:vehicles_agencies_routes) { Frizzle::Vehicles.find_by_agencies_and_routes("24", ["4003034","4003038"]) }

    before do
      VCR.insert_cassette 'vehicles_agencies_routes'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Vehicles.find_by_agencies_and_routes("24", ["4003034","4003038"])
    end
  end

  describe "find stops with agencies and geo area" do
    let(:vehicles_agencies_geo_area) { Frizzle::Vehicles.find_by_agencies_and_geo_area(24, [35.98974,-78.90292]) }

    before do
      VCR.insert_cassette 'vehicles_agencies_geo_area'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Vehicles.find_by_agencies_and_geo_area(24, [35.98974,-78.90292])
    end
  end

  describe "find stops with agencies, routes, geo area" do
    let(:vehicles_agencies_routes_geo_area) { Frizzle::Vehicles.find_by_agencies_and_routes_geo_area(24, ["4003034","4003038"], [35.98974,-78.90292]) }

    before do
      VCR.insert_cassette 'vehicles_agencies_routes_geo_area'
    end

    after do
      VCR.eject_cassette
    end

    it "records the fixture" do
      Frizzle::Vehicles.find_by_agencies_and_routes_and_geo_area(24, ["4003034","4003038"], [35.98974,-78.90292])
    end
  end

end
